==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QLayout_shell.h <==
#ifndef QLAYOUT_SHELL_H
#define QLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qlayout.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QLayout_shell : public QLayout, public QtJambiShellInterface
{
public:
    QLayout_shell();
    QLayout_shell(QWidget* parent0);
    ~QLayout_shell() override;

    void addItem(QLayoutItem* arg__1) override;
    void childEvent(QChildEvent* e0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSizePolicy::ControlTypes controlTypes() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientations expandingDirections() const override;
    QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    int indexOf(QWidget* arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    QLayoutItem* itemAt(int index0) const override;
    QLayout* layout() override;
    QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    QSize minimumSize() const override;
    void setGeometry(const QRect& arg__1) override;
    QSize sizeHint() const override;
    QSpacerItem* spacerItem() override;
    QLayoutItem* takeAt(int index0) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* widget() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QLayout_access : public QLayout
{
    void __qt_addChildLayout_QLayout_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID l0);
    void __qt_addChildWidget_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID w0);
    jboolean __qt_adoptLayout_QLayout_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID layout0);
    jobject __qt_alignmentRect_cref_QRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    void __qt_widgetEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_addItem_QLayoutItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_childEvent_QChildEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jint __qt_controlTypes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_expandingDirections_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_geometry_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasHeightForWidth_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_heightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jint __qt_indexOf_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    void __qt_invalidate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isEmpty_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_itemAt_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jobject __qt_layout(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_maximumSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_minimumHeightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jobject __qt_minimumSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setGeometry_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_spacerItem(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_takeAt_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
    jobject __qt_widget(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QLAYOUT_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiWidgets/QLayout_shell.h <==
#ifndef QLAYOUT_SHELL_H
#define QLAYOUT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qlayout.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtWidgets/qlayoutitem.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QLayout_shell : public QLayout, public QtJambiShellInterface
{
public:
    QLayout_shell(QWidget* parent0 = nullptr);
    ~QLayout_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QLayout_mshell;
    friend class QLayout_oshell;
};


class QLayout_mshell : public QLayout_shell
{
public:
    using QLayout_shell::QLayout_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QLayout_oshell : public QLayout_mshell
{
public:
    using QLayout_mshell::QLayout_mshell;
    void addItem(QLayoutItem* arg__1) override;
    void childEvent(QChildEvent* e0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSizePolicy::ControlTypes controlTypes() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    Qt::Orientations expandingDirections() const override;
    QRect geometry() const override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    int indexOf(const QLayoutItem* arg__1) const override;
    int indexOf(const QWidget* arg__1) const override;
    void invalidate() override;
    bool isEmpty() const override;
    QLayoutItem* itemAt(int index0) const override;
    QLayout* layout() override;
    QSize maximumSize() const override;
    int minimumHeightForWidth(int arg__1) const override;
    QSize minimumSize() const override;
    QLayoutItem* replaceWidget(QWidget* from0, QWidget* to1, Qt::FindChildOptions options2) override;
    void setGeometry(const QRect& arg__1) override;
    void setSpacing(int arg__1) override;
    QSize sizeHint() const override;
    QSpacerItem* spacerItem() override;
    int spacing() const override;
    QLayoutItem* takeAt(int index0) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* widget() const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QLayout_access : public QLayout
{
    void __qt_addChildLayout_QLayout_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID l0);
    void __qt_addChildWidget_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID w0);
    jboolean __qt_adoptLayout_QLayout_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID layout0);
    jobject __qt_alignmentRect_cref_QRect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    void __qt_widgetEvent_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_addItem_QLayoutItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_childEvent_QChildEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jint __qt_controlTypes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_expandingDirections_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_geometry_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasHeightForWidth_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_heightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jint __qt_indexOf_const_QLayoutItem_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    jint __qt_indexOf_const_QWidget_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1) const;
    void __qt_invalidate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isEmpty_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_itemAt_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jobject __qt_layout(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_maximumSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_minimumHeightForWidth_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1) const;
    jobject __qt_minimumSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_replaceWidget_QWidget_ptr_QWidget_ptr_Qt_FindChildOptions(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID from0, QtJambiNativeID to1, jint options2);
    void __qt_setGeometry_cref_QRect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_setWidgetSpacing_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1);
    jobject __qt_sizeHint_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_spacerItem(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_widgetSpacing_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_takeAt_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
    jobject __qt_widget_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QLAYOUT_SHELL_H
